import { Schema, model } from 'mongoose';
import bcrypt from 'bcrypt';
import {nanoid} from 'nanoid';

const SALT_WORK_FACTOR= 10;

// 1. Create an interface representing a document in MongoDB.
interface IUser {
  name: string;
  surname: string;
  email: string;
  displayName: string;
  password:string;
  role: string;
}

// 2. Create a Schema corresponding to the document interface.
const UserSchema = new Schema<IUser>({
  name: { type: String, required: true },
  surname: { type: String, required: true },
  email: { type: String, required: true },
  displayName: { type: String, required: true },
  password: { type: String, required: true },
  role:{type:String,default: 'user',enum:['user','admin']}
});


// How does next's type defined?
UserSchema.pre('save', async function(next:any):Promise<void>{
  if(!this.isModified('password')) return next();
  console.log('next', next)
  const salt = await bcrypt.genSalt(SALT_WORK_FACTOR);
  const hash = await bcrypt.hash(this.password, salt);
  this.password = hash;
  next();
})

UserSchema.set('toJSON',{
  transform:(doc:any, ret:any, options:any)=>{
      delete ret.password;
      return ret;
  }
})

UserSchema.methods.checkPassword =function(password:string):Promise<boolean>{
  return bcrypt.compare(password,this.password);
}

UserSchema.methods.generateToken =function(){
  this.token=nanoid();
}



// 3. Create a Model.
const User = model<IUser>('User', UserSchema);


export default User;
