import {Routes, Route, Outlet, Navigate, BrowserRouter} from "react-router-dom";
import {Container} from "@mui/material";
import {useSelector} from "react-redux";
import AppToolbar from "./components/UI/AppToolBar/AppToolBar";
import MyTasks from './containers/MyTasks/MyTasks'

const ProtectedRoute = ({isAllowed, roles, redirectUrl, children}) => {
  const user = useSelector(state => state.users?.user);
  if (!isAllowed && !roles?.includes(user?.role)) {
      return <Navigate to={redirectUrl} />
  }
  return children || <Outlet />;
};

const App = () => {
    const user = useSelector(state => state.users?.user);
    return (
    <BrowserRouter>
      <Routes>
          <Route element={
            <>
              <AppToolbar/>
              <main>
                  <Container >
                      <Outlet/>
                  </Container>
              </main>
            </>
          }>

            <Route path={"/"} element={
              <ProtectedRoute
                  isAllowed={user}
                  redirectUrl={"/log-in"}
              >
                  <h1>week page</h1>
              </ProtectedRoute>
            }/>

            <Route path={"/week"} element={
              <ProtectedRoute
                  isAllowed={user}
                  redirectUrl={"/log-in"}
              >
                  <h1>week page</h1>
              </ProtectedRoute>
            }/>

            <Route path={"/month"} element={
              <ProtectedRoute
                  isAllowed={user}
                  redirectUrl={"/log-in"}
              >
                  <h1>month page</h1>
              </ProtectedRoute>
            }/>

            <Route path={"/my-tasks"} element={
              <ProtectedRoute
                  isAllowed={user}
                  redirectUrl={"/log-in"}
              >
                    <MyTasks/>
              </ProtectedRoute>
            }/>

            <Route path={"/profile/:id"} element={
              <ProtectedRoute
                  isAllowed={user}
                  redirectUrl={"/log-in"}
              >
                  <h1>profile page</h1>
              </ProtectedRoute>
            }/>

            <Route path={"/workers-tasks"} element={
              <ProtectedRoute
                  roles={["superuser"]}
                  redirectUrl={"/"}
              >
                  <h1>workers tasks page</h1>
              </ProtectedRoute>
            }/>

            <Route path={"/sign-up"} element={
              <ProtectedRoute
                  roles={["superuser"]}
                  redirectUrl={"/"}
              >
                  <h1>sign-up page</h1>
              </ProtectedRoute>
            }/>

            <Route path={"/log-in"} element={<h1>log-in page</h1>}/>
            <Route path='*' element={<h1>404</h1>}/>
          </Route>
      </Routes>
    </BrowserRouter>
    )
};

export default App;
