import * as React from 'react';
import Box from '@mui/material/Box';
import Table from '@mui/material/Table';
import TableBody from '@mui/material/TableBody';
import TableCell from '@mui/material/TableCell';
import TableContainer from '@mui/material/TableContainer';
import TablePagination from '@mui/material/TablePagination';
import TableRow from '@mui/material/TableRow';
import Paper from '@mui/material/Paper';
import IconButton from '@mui/material/IconButton';
import Tooltip from '@mui/material/Tooltip';
import DeleteIcon from '@mui/icons-material/Delete';
import { useState } from "react";
import Input from '@mui/material/Input';
import { Done } from '@mui/icons-material';
import {Edit} from '@mui/icons-material'
import TaskModal from '../../components/UI/TaskModal/TaskModal'
import EnhancedTableHead from './MyTasksHeader/MyTasksHeader';
import MyTaskToolBar from '../../components/MyTaskToolBar/MyTaskToolBar'

function descendingComparator(a, b, orderBy) {
  if (b[orderBy] < a[orderBy]) {
    return -1;
  }
  if (b[orderBy] > a[orderBy]) {
    return 1;
  }
  return 0;
}

function getComparator(order, orderBy) {
  return order === 'desc'
    ? (a, b) => descendingComparator(a, b, orderBy)
    : (a, b) => -descendingComparator(a, b, orderBy);
}


function stableSort(array, comparator) {
  const stabilizedThis = array.map((el, index) => [el, index]);
  stabilizedThis.sort((a, b) => {
    const order = comparator(a[0], b[0]);
    if (order !== 0) {
      return order;
    }
    return a[1] - b[1];
  });
  return stabilizedThis.map((el) => el[0]);
}


const CustomTableCell = ({ task, name, onChange, onModalOpen }) => {
  return (
    <TableCell align="left" style={{ width: "130px", height: "40px" }}>
      {task.isEditMode ? (
        <Input
          value={task[name]}
          name={name}
          onChange={(e) => onChange(e, task)}
          style={{ width: "130px", height: "40px" }}
        />
      ) : onModalOpen ? (
        <span style={{ width: "100%" }} onClick={(e) => onModalOpen(e, task)}>
          {task[name]}
        </span>
      ) : (
        task[name]
      )}
    </TableCell>
  );
};


export default function EnhancedTable() {
  const [order, setOrder] = React.useState('asc');
  const [orderBy, setOrderBy] = React.useState('id');
   const [page, setPage] = React.useState(0);
   const [rowsPerPage, setRowsPerPage] = React.useState(5);

const exampleTasks=[
  {
    user:"first",
    title:"задача1",
    description:"описание задачи11111",
    priority:"A",
    author:"Ivan",
    executor:"Arman",
    dateTimeStart:"26.10.2022",
    dateTimeDue:"27.10.2022",
    id:1,
    dateCreated:"26.10.2022"
  },
  {
      user:"second",
      title:"задача2",
      description:"описание задачи222222",
      author:"Ivan",
      executor:"Elena",
      priority:"B",
      dateTimeStart:"26.10.2022",
      dateTimeDue:"27.10.2022",
      id:2,
      dateCreated:"26.10.2022"
    },
    {
      user:"theird",
      title:"задача3",
      description:"описание задачи333333bjh,khkuhlhvilv hmgjtycikg mkgyxxkjfkkmgyhkfrdtseygdtjtuliuo8plfyvguh,bb",
      author:"Artem",
      executor:"Bota",
      priority:"B",
      dateTimeStart:"30.10.2022",
      dateTimeDue:"02.11.2022",
      id:3,
      dateCreated:"27.10.2022",

    }
  ]

  const formattedTasks = exampleTasks.map((t)=> {return {...t, isEditableMode: false}})
 
  const [tasks,setTasks]=useState(formattedTasks)
  
  const onToggleEditMode = id => {
    setTasks(state => {
      return tasks.map(task => {
        if (task.id === id) {
          return { ...task, isEditMode: !task.isEditMode };
        }
        return task;
      });
    });
  };
  
  const onChange = (e, task) => {
    const value = e.target.value;
    const name = e.target.name;
    const { id } = task;
    const newTasks = tasks.map(task => {
      if (task.id === id) {
        return { ...task, [name]: value };
      }
      return task;
    });
    setTasks(newTasks);
  };

  const handleRequestSort = (event, property) => {
    const isAsc = orderBy === property && order === 'asc';
    setOrder(isAsc ? 'desc' : 'asc');
    setOrderBy(property);
  };

  
  const deleteTask=()=>{
    // удалить по id из selected
    }

  const handleChangePage = (event, newPage) => {
    setPage(newPage);
  };

  const handleChangeRowsPerPage = (event) => {
    setRowsPerPage(parseInt(event.target.value, 10));
    setPage(0);
  };

  
  const [modal, setModal] =useState({
    open: false,
    task: null
  });
  const onModalOpen = (event, task) => {
    console.log(event,task)
    event.stopPropagation();
    setModal({ ...modal, open: true, task});
  };
  const handleClose = () => {
    setModal({ ...modal, open: false, task: null });
  };
  
  
  return (
    <Box sx={{ width: 'fullwidth' }}>
      <Paper sx={{ width: '100%', mb: 2 }}>

      <MyTaskToolBar/>

        <TableContainer>
          <Table
            sx={{ minWidth: 750 }}
            aria-labelledby="tableTitle"
          >
            <EnhancedTableHead
              order={order}
              orderBy={orderBy}
              onRequestSort={handleRequestSort}
              rowCount={tasks.length}
            />
            <TableBody>

              {stableSort(tasks, getComparator(order, orderBy))
                .slice(page * rowsPerPage, page * rowsPerPage + rowsPerPage)
                .map((task, index) => {
                
                  return (
                    <>
                    
                    <TableRow
                      hover
                      key={task.id}                    
                    >
                     <TableCell
                        component="th"
                        scope="row"
                        padding="none"
                      ></TableCell>  
                        <CustomTableCell {...{ task, name: "priority", onChange }} />
                        <CustomTableCell {...{ task, name: "dateCreated", onChange }} />
                        <CustomTableCell {...{ task, name: "title", onChange, onModalOpen}}  />
                        <CustomTableCell {...{ task, name: "author", onChange }} />
                        <CustomTableCell {...{ task, name: "dateTimeStart", onChange }} />
                        <CustomTableCell {...{ task, name: "dateTimeDue", onChange }} />
                        <CustomTableCell {...{ task, name: "done", onChange }} />
                                               

                      <TableCell >
               
                {task.isEditMode ? (
                 
                    <IconButton
                      aria-label="done"
                      onClick={() => onToggleEditMode(task.id)}
                    >
                      <Done/>
                    </IconButton>
                     
                ) : (
                  <IconButton
                    aria-label="delete"
                    onClick={() => onToggleEditMode(task.id)}
                  >
                    <Edit/>
                  </IconButton>
                )}
              </TableCell>
                     <TableCell>
                      <Tooltip title="Delete">
                      <IconButton onClick={(id)=>{deleteTask(id)}}>
                        <DeleteIcon />
                      </IconButton>
                      </Tooltip>
                    </TableCell>
                    </TableRow>
                    
                    </>
                  );
                })}
           
            </TableBody>
          </Table>
        </TableContainer>
        <TablePagination
          rowsPerPageOptions={[5,10, 25]}
          component="div"
          count={tasks.length}
          rowsPerPage={rowsPerPage}
          page={page}
          onPageChange={handleChangePage}
          onRowsPerPageChange={handleChangeRowsPerPage}
        />
      </Paper>
        <TaskModal
          task={modal.task}
          open={modal.open}
          handleClose={handleClose}
                        
        /> 
    </Box>
  );
}
